@@ -190,9 +190,9 @@ get_ifb_for_if() {
 verify_qdisc() {
     local qdisc=$1
     local supported="$2"
-    local not=
     local ifb=TMP_IFB_4_SQM
     local root_string="root" # this works for most qdiscs
+    local args=""
 
     if [ -n "$supported" ]; then
         local found=0
@@ -205,12 +205,17 @@ verify_qdisc() {
     case $qdisc in
         #ingress is special
         ingress) root_string="" ;;
+        #cannot instantiate tbf without args
+        tbf) args="limit 1 burst 1 rate 1kbps" ;;
     esac
 
-    $TC qdisc replace dev $ifb $root_string $qdisc
+    $TC qdisc replace dev $ifb $root_string $qdisc $args
     res=$?
-    [ "$res" = "0" ] || not="NOT "
-    sqm_debug "QDISC $qdisc is ${not}useable."
+    if [ "$res" = "0" ] ; then
+        sqm_debug "QDISC $qdisc is useable."
+    else
+        sqm_error "QDISC $qdisc is NOT useable."
+    fi
     delete_ifb $ifb
     return $res
 }
@@ -379,8 +384,9 @@ get_burst() {
 
     # 10 MTU burst can itself create delay under CPU load.
     # It will need to all wait for a hardware commit.
+    # Note the lean mixture at high bandwidths for upper limit.
     BANDWIDTH_L=$(( ${MTU} *  2 * 8 ))
-    BANDWIDTH_H=$(( ${MTU} * 10 * 8 ))
+    BANDWIDTH_H=$(( ${MTU} * 18 * 8 ))
 
 
     if [ ${BANDWIDTH} -gt ${BANDWIDTH_H} ] ; then
